<?php

header('Content-Type: application/json');

$retour = array();

try {
    // Connexion à la base de données
    $connexion = new PDO('mysql:host=localhost;dbname=FasCars', 'mariadb', 'mariadb*1');
    $connexion->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Détermine la page à afficher et le nombre d'éléments par page
    $page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
    $elementsParPage = 10; // Changez cela en fonction du nombre de contrôles techniques que vous voulez afficher par page

    // Calculer l'offset pour la requête SQL
    $offset = ($page - 1) * $elementsParPage;

    // Requête pour récupérer la liste des Contrôles Technique avec pagination
    $requestControle = $connexion->prepare("
        SELECT ControleTechnique.*, V.*, Marque.nom AS nom_marque, Modele.nom AS nom_modele, TypeVehicule.nomType AS nom_type
        FROM ControleTechnique
        INNER JOIN Vehicule AS V ON ControleTechnique.idVehicule = V.idVehicule
        JOIN Marque ON V.idMarque = Marque.idMarque
        JOIN TypeVehicule ON V.idTypeVehicule = TypeVehicule.idTypeVehicule
        JOIN Modele ON V.idModele = Modele.idModele
        LIMIT :offset, :elementsParPage
    ");
    $requestControle->bindParam(':offset', $offset, PDO::PARAM_INT);
    $requestControle->bindParam(':elementsParPage', $elementsParPage, PDO::PARAM_INT);
    $requestControle->execute();
    $controle = $requestControle->fetchAll(PDO::FETCH_ASSOC);

    // Requête pour compter le nombre total d'éléments (contrôles techniques)
    $countTotalControle = $connexion->query("SELECT COUNT(*) AS total FROM ControleTechnique");
    $totalControle = $countTotalControle->fetchColumn();

    // Calcul du nombre total de pages
    $totalPages = ceil($totalControle / $elementsParPage);

    $hasMore = count($controle) == $elementsParPage; // Vérifie s'il y a plus de contrôles techniques à charger

    $retour["success"] = true;
    $retour["controle"] = $controle;
    $retour["totalPages"] = $totalPages; // Ajoute le nombre total de pages à la réponse JSON
    $retour["hasMore"] = $hasMore; // Ajoute l'indicateur hasMore à la réponse JSON

} catch (PDOException $ex) {
    $retour["success"] = false;
    $retour["error"] = "Erreur de connexion à la base de données: " . $ex->getMessage();
}

// Envoi de la réponse JSON
echo json_encode($retour);
?>
