<?php

header('Content-Type: application/json');

$retour = array();

try {
    // Connexion à la base de données
    $connexion = new PDO('mysql:host=localhost;dbname=FasCars', 'mariadb', 'mariadb*1');
    $connexion->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Détermine la page à afficher et le nombre d'éléments par page
    $page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
    $elementsParPage = 10; // Changez cela en fonction du nombre des infractions que vous voulez afficher par page

    // Calculer l'offset pour la requête SQL
    $offset = ($page - 1) * $elementsParPage;

    // Requête pour récupérer la liste des infractions avec pagination
    $requestInfractions = $connexion->prepare("SELECT Infractions.*, V.*, Marque.nom AS nom_marque, Modele.nom AS nom_modele, TypeVehicule.nomType AS nom_type, Clients.nom AS nom_client, Clients.prenom AS prenom_client
        FROM Infractions
        INNER JOIN Vehicule AS V ON Infractions.idVehicule = V.idVehicule
        JOIN Marque ON V.idMarque = Marque.idMarque
        JOIN TypeVehicule ON V.idTypeVehicule = TypeVehicule.idTypeVehicule
        JOIN Modele ON V.idModele = Modele.idModele
        JOIN Clients ON Infractions.idClient = Clients.idClient
        LIMIT :offset, :elementsParPage");
    $requestInfractions->bindParam(':offset', $offset, PDO::PARAM_INT);
    $requestInfractions->bindParam(':elementsParPage', $elementsParPage, PDO::PARAM_INT);
    $requestInfractions->execute();
    $infractions = $requestInfractions->fetchAll(PDO::FETCH_ASSOC);

    // Requête pour compter le nombre total d'infractions
    $countTotalInfractions = $connexion->query("SELECT COUNT(*) AS total FROM Infractions");
    $totalInfractions = $countTotalInfractions->fetchColumn();

    // Calcul du nombre total de pages
    $totalPages = ceil($totalInfractions / $elementsParPage);

    // Vérifie s'il y a des infractions
    $hasMore = count($infractions) == $elementsParPage; // Vérifie s'il y a plus d'infractions à charger

    $retour["success"] = true;
    $retour["infractions"] = $infractions;
    $retour["totalPages"] = $totalPages; // Ajoute le nombre total de pages à la réponse JSON
    $retour["hasMore"] = $hasMore; // Ajoute l'indicateur hasMore à la réponse JSON

} catch (PDOException $ex) {
    $retour["success"] = false;
    $retour["error"] = "Erreur de connexion à la base de données: " . $ex->getMessage();
}

// Envoi de la réponse JSON
echo json_encode($retour);
?>
