<?php
header('Content-Type: application/json');
$retour = array();

try {
    // Récupérer l'ID du genre à supprimer à partir des données envoyées en POST
    $idGenre = isset($_POST['idGenre']) ? $_POST['idGenre'] : null;

    // Vérifier si l'ID du genre à supprimer est présent
    if ($idGenre === null) {
        throw new Exception("L'ID du genre à supprimer n'a pas été spécifié.");
    }

    // Connexion à la base de données
    $connexion = new PDO('mysql:host=localhost;dbname=FasCars', 'mariadb', 'mariadb*1');
    $connexion->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Vérifier s'il y a des clients associés au genre
    $requeteVerifClients = $connexion->prepare("SELECT COUNT(*) FROM Clients WHERE idGenre = :idGenre");
    $requeteVerifClients->bindParam(':idGenre', $idGenre, PDO::PARAM_INT);
    $requeteVerifClients->execute();
    $nombreClients = $requeteVerifClients->fetchColumn();

    if ($nombreClients > 0) {
        // Il y a des clients associés au genre, donc la suppression n'est pas possible
        $retour["success"] = false;
        $retour["message"] = "Impossible de supprimer le genre car des clients y sont associés.";
    } else {
        // Aucun client associé au genre, on peut procéder à la suppression
        $connexion->beginTransaction();

        // Supprimer d'abord tous les enregistrements associés dans les autres tables

        // Ensuite, supprimer l'enregistrement dans la table Genre
        $requeteSuppressionGenre = $connexion->prepare("DELETE FROM Genre WHERE idGenre = :idGenre");
        $requeteSuppressionGenre->bindParam(':idGenre', $idGenre, PDO::PARAM_INT);
        $requeteSuppressionGenre->execute();

        // Si toutes les requêtes de suppression réussissent, valider la transaction
        $connexion->commit();

        // Informer que la suppression a réussi
        $retour["success"] = true;
        $retour["message"] = "Le genre et tous les enregistrements associés ont été supprimés avec succès.";
    }

} catch (PDOException $ex) {
    // En cas d'erreur, annuler la transaction et retourner l'erreur
    $connexion->rollBack();
    $retour["success"] = false;
    $retour["error"] = "Erreur de connexion à la base de données: " . $ex->getMessage();
} catch (Exception $ex) {
    // En cas d'erreur, retourner l'erreur
    $connexion->rollBack();
    $retour["success"] = false;
    $retour["error"] = $ex->getMessage();
}

// Envoi de la réponse JSON
echo json_encode($retour);
?>
