<?php

header('Content-Type: application/json');

$retour = array();

try {
    // Connexion à la base de données
    $connexion = new PDO('mysql:host=localhost;dbname=FasCars', 'mariadb', 'mariadb*1');
    $connexion->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

    // Détermine la page à afficher et le nombre de véhicules par page
    $page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
    $clientsParPage = 10; // Changez cela en fonction de combien de clients vous voulez par page

    // Calculer l'offset pour la requête SQL
    $offset = ($page - 1) * $clientsParPage;

    // Requête pour récupérer la liste des véhicules avec pagination
    $requestVehicules = $connexion->prepare("
    SELECT Vehicule.*, 
       Marque.nom AS nom_marque, 
       Modele.nom AS nom_modele, 
       TypeVehicule.nomType AS nom_type, 
       Statut.Statut AS statut,
       PhotosVehicule.nomPhoto AS nom_photo,
       PhotosVehicule.imageVehicule AS image_vehicule
FROM Vehicule
JOIN Marque ON Vehicule.idMarque = Marque.idMarque
JOIN TypeVehicule ON Vehicule.idTypeVehicule = TypeVehicule.idTypeVehicule
JOIN Modele ON Vehicule.idModele = Modele.idModele
JOIN Statut ON Vehicule.idStatut = Statut.idStatut
LEFT JOIN PhotosVehicule ON Vehicule.idVehicule = PhotosVehicule.idVehicule
        LIMIT :offset, :clientsParPage
    ");
    $requestVehicules->bindParam(':offset', $offset, PDO::PARAM_INT);
    $requestVehicules->bindParam(':clientsParPage', $clientsParPage, PDO::PARAM_INT);
    $requestVehicules->execute();
    $vehicules = $requestVehicules->fetchAll(PDO::FETCH_ASSOC);

    // Requête pour compter le nombre total de véhicules
    $countTotalVehicules = $connexion->query("SELECT COUNT(*) AS total FROM Vehicule");
    $totalVehicules = $countTotalVehicules->fetchColumn();

    // Calcul du nombre total de pages
    $totalPages = ceil($totalVehicules / $clientsParPage);

    // Vérifie s'il y a des véhicules
    $retour["success"] = true;
    $retour["vehicules"] = $vehicules;
    $retour["totalPages"] = $totalPages; // Ajoute le nombre total de pages à la réponse JSON

} catch (PDOException $ex) {
    $retour["success"] = false;
    $retour["error"] = "Erreur de connexion à la base de données: " . $ex->getMessage();
}

// Envoi de la réponse JSON
echo json_encode($retour);
?>
