<?php
// Fichier : editSuplementsVehicules.php

// Vérification de la méthode de requête
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    // Méthode non autorisée
    http_response_code(405);
    echo json_encode(['message' => 'Méthode non autorisée']);
    exit;
}

// Vérification du type de contenu
if (strpos($_SERVER['CONTENT_TYPE'], 'multipart/form-data') !== 0) {
    // Type de contenu non pris en charge
    http_response_code(415);
    echo json_encode(['message' => 'Type de contenu non pris en charge']);
    exit;
}

// Vérification des données requises
if (!isset($_POST['idSupplements']) || !isset($_POST['idClient']) || !isset($_POST['idVehicule']) || !isset($_POST['idSupplementsVehicule'])) {
    // Données manquantes
    http_response_code(400);
    echo json_encode(['message' => 'Paramètres manquants']);
    exit;
}

// Récupération des données
$idSupplements = $_POST['idSupplements'];
$idClient = $_POST['idClient'];
$idVehicule = $_POST['idVehicule'];
$idSupplementsVehicule = $_POST['idSupplementsVehicule'];

// Connexion à la base de données (supposons que vous utilisez PDO)
try {
    // Connexion à la base de données
	$connexion = new PDO('mysql:host=localhost;dbname=FasCars', 'mariadb', 'mariadb*1');
	$connexion->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);

} catch (PDOException $e) {
    http_response_code(500);
    echo json_encode(['message' => 'Erreur de connexion à la base de données']);
    exit;
}

// Préparation de la requête SQL
$sql = "UPDATE SupplementsVehicule SET idClient = :idClient, idVehicule = :idVehicule, idSupplements = :idSupplements WHERE idSupplementsVehicule = :idSupplementsVehicule";


// Exécution de la requête préparée
try {
    $stmt = $connexion->prepare($sql);
    $stmt->bindParam(':idClient', $idClient);
    $stmt->bindParam(':idVehicule', $idVehicule);
    $stmt->bindParam(':idSupplements', $idSupplements);
    $stmt->bindParam(':idSupplementsVehicule', $idSupplementsVehicule);
    $stmt->execute();
    http_response_code(200);
    echo json_encode(['success' => true, 'message' => 'Données mises à jour avec succès']);
    exit;
} catch (PDOException $e) {
    http_response_code(500);
    echo json_encode(['message' => 'Erreur lors de la mise à jour des données']);
    exit;
}
?>
