import React from 'react';
import { View, Text, StyleSheet } from 'react-native';
import { Slider } from 'react-native-elements';

const ProgressBarSlider = ({ label, value, onValueChange, maximumValue, step }) => {
  maximumValue = maximumValue || 100; // Défaut à 100 si maximumValue n'est pas fourni
  step = step || 1; // Défaut à 1 si step n'est pas fourni

  return (
    <View style={styles.container}>
      <Text style={styles.label}>{label}</Text>
      <Slider
        value={value}
        onValueChange={onValueChange}
        maximumValue={maximumValue}
        step={step}
        style={styles.slider}
        thumbStyle={styles.thumb}
        trackStyle={styles.track}
        thumbTintColor="#007BFF"
        minimumTrackTintColor="#007BFF"
        maximumTrackTintColor="#CCCCCC"
      />
      <Text style={styles.valueText}>{value} %</Text> 
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    marginBottom: 20,
    backgroundColor: '#FFFFFF',
    borderRadius: 10,
    padding: 15,
    shadowColor: '#000',
    shadowOpacity: 0.2,
    shadowRadius: 3,
    elevation: 3,
    width: '90%',
    alignSelf: 'center',
  },
  label: {
    textAlign: 'center',
    fontSize: 18,
    marginBottom: 10,
    color: '#333',
  },
  slider: {
    marginBottom: 10,
  },
  thumb: {
    width: 20,
    height: 20,
    backgroundColor: '#007BFF',
    borderRadius: 10,
  },
  track: {
    height: 4,
    borderRadius: 2,
    backgroundColor: '#CCCCCC',
  },
  valueText: {
    textAlign: 'center',
    fontSize: 16,
    color: '#666',
  },
});

export default ProgressBarSlider;
