import React, { useState } from 'react';
import { connect } from 'react-redux';
import { View, Text, StyleSheet, TouchableOpacity, Alert, BackHandler } from 'react-native';
import { useNavigation } from '@react-navigation/native'; 
import { logout } from '../actions/userActions';

// Fonction pour afficher les informations de l'utilisateur
const UserInfo = ({ user, logout }) => {
  const [showMenu, setShowMenu] = useState(false);
  const navigation = useNavigation(); 

  const handleToggleMenu = () => {
    setShowMenu(!showMenu); 
  };
  // Fonction pour gérer la déconnexion
  const handleLogout = () => {
    setShowMenu(false); 
    logout(); 
    navigation.navigate('HomeScreen'); 
  };
 // Fonction pour quitter l'application
  const handleExitApp = () => {
    Alert.alert(
      'Quitter l\'application',
      'Êtes-vous sûr de vouloir quitter l\'application?',
      [
        { text: 'Annuler', style: 'cancel' },
        { text: 'Quitter', onPress: () => BackHandler.exitApp() }
      ]
    );
  };

  const avatarText = user ? user.nom.slice(0, 2).toUpperCase() : '';

  return (
    <View style={styles.container}>
      <TouchableOpacity onPress={handleToggleMenu}> 
        <View style={styles.badgeContainer}>
          <View style={styles.circle}>
            <Text style={styles.avatarText}>{avatarText}</Text>
          </View>
        </View>
      </TouchableOpacity>
      {showMenu && (
        <View style={styles.menuContainer}>
          <TouchableOpacity onPress={handleLogout}>
            <Text style={styles.menuItem}>Déconnexion</Text>
          </TouchableOpacity>
          <TouchableOpacity onPress={handleExitApp}>
            <Text style={styles.menuItem}>Quitter l'application</Text>
          </TouchableOpacity>
        </View>
      )}
    </View>
  );
};

const mapStateToProps = (state) => ({
  user: state.user.user,
});

const mapDispatchToProps = (dispatch) => ({
  logout: () => dispatch(logout()), 
});

const styles = StyleSheet.create({
  container: {
    top: 10,
    left: "42.5%",
    alignItems: 'center',
    justifyContent: 'center',
  },
  circle: {
    width: 60,
    height: 60,
    borderRadius: 30,
    backgroundColor: '#58A681',
    alignItems: 'center',
    justifyContent: 'center',
  },
  badgeContainer: {
    paddingVertical: 2,
    alignItems: 'center',
  },
  avatarText: {
    color: '#fff',
    fontSize: 20,
    fontWeight: 'bold',
  },
  menuContainer: {
    marginTop: 10,
    paddingVertical: 5,
    paddingHorizontal: 5,
    backgroundColor: '#B4D9C4',
    borderRadius: 10,
    shadowColor: '#000',
    shadowOffset: { width: 0, height: 2 },
    shadowOpacity: 0.3,
    shadowRadius: 3,
    elevation: 5,
    zIndex: 1,
  },
  menuItem: {
    fontSize: 16,
    paddingVertical: 10,
    paddingHorizontal: 10,
    backgroundColor: '#1D7342',
    borderRadius: 10,
    shadowColor: '#000',
    shadowOffset: { width: 0, height: 2 },
    shadowOpacity: 0.3,
    shadowRadius: 3,
    elevation: 5,
    color: '#fff',
    marginBottom: 5,
  },
});

export default connect(mapStateToProps, mapDispatchToProps)(UserInfo);
