import React, { useState, useEffect } from 'react';
import { StyleSheet, Alert, ScrollView, View } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native';
import DropDown from '../../Components/DropDown';
import Header from '../../Components/Header';
import InputText from '../../Components/InputText';
import SelectedImageServer from '../../Components/SelectedImageServeur';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

const AccidentDetails = ({ route }) => {
    const { selectedItem } = route.params;
    const [idAccident, setIdAccident] = useState(selectedItem.idAccident);
    const [NumeroConstat, setNumeroConstat] = useState(selectedItem.NumeroConstat);
    const [Date, setDate] = useState(selectedItem.Date);
    const [constatImage, setConstatImage] = useState(selectedItem.imageConstat);
    const [idAssurance, setIdAssurance] = useState(selectedItem.idAssurance);
    const [idVehicule, setIdVehicule] = useState(selectedItem.idVehicule);
    const [idClient, setIdClient] = useState(selectedItem.idClient);
    const navigation = useNavigation();
    const [clients, setClients] = useState([]);
    const [vehicules, setVehicules] = useState([]); 
  const [selectedVehicule, setSelectedVehicule] = useState(selectedItem.idVehicule);
  const [assurances, setAssurances] = useState([]);
   
 
    useEffect(() => {
       fetchAllAssurances();
        fetchAllClients();
        fetchAllVehicules();
    }, []);


// Fonction pour récupérer toutes les assurances
const fetchAllAssurances = async () => {
    try {
        let allAssurances = [];
        let currentPage = 1;
        let morePages = true;

        while (morePages) {
            const response = await fetch(`https://sites.freeboxos.fr/Api/Administratif/getAssurances.php?page=${currentPage}`);
            const json = await response.json();
            if (json.success) {
                allAssurances = [...allAssurances, ...json.assurances.map(assurance => ({
                    label: `${assurance.idAssurance} - ${assurance.nomAssurance}`,
                    value: assurance.idAssurance
                }))];
                currentPage++;
                morePages = currentPage <= json.totalPages;
            } else {
                console.error(json.message || json.error);
                break;
            }
        }

        setAssurances(allAssurances);
    } catch (error) {
        Alert.alert('Une erreur est survenue lors de la récupération des assurances.'); 
    }
};


      // Fonction pour récupérer tous les clients
      const fetchAllClients = async () => {
        try {
            let allClients = [];
            let currentPage = 1;
            let morePages = true;
    
            while (morePages) {
                const response = await fetch(`https://sites.freeboxos.fr/Api/Clients/getClients.php?page=${currentPage}`);
                const json = await response.json();
                if (json.success) {
                    allClients = [...allClients, ...json.clients.map(client => ({ label: `${client.idClient} - ${client.Genre} ${client.nom}`, value: client.idClient }))];
                    currentPage++;
                    morePages = currentPage <= json.totalPages;
                } else {
                    console.error(json.message || json.error);
                    break;
                }
            }
    
            setClients(allClients);
        } catch (error) {
           Alert.alert('Une erreur est survenue lors de la récupération des clients.');
        }
    };

   // Fonction pour récupérer les véhicules
   const fetchAllVehicules = async () => {
    try {
        let allVehicules = [];
        let currentPage = 1;
        let morePages = true;

        while (morePages) {
            const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/getVehicules.php?page=${currentPage}`);
            const json = await response.json();
            if (json.success) {
                allVehicules = [...allVehicules, ...json.vehicules.map(vehicule => ({ label: `${vehicule.nom_marque} - ${vehicule.Immat}`, value: vehicule.idVehicule }))];
                currentPage++;
                morePages = currentPage <= json.totalPages;
            } else {
                console.error(json.message || json.error);
                break;
            }
        }

        setVehicules(allVehicules);
    } catch (error) {
       Alert.alert('Une erreur est survenue lors de la récupération des véhicules.');
    }
};


// Fonction pour modifier un élément
    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idAccident', selectedItem.idAccident);
            formData.append('NumeroConstat', NumeroConstat);
            formData.append('Date', Date);
            formData.append('idAssurance', idAssurance);
            formData.append('idVehicule', idVehicule);
            formData.append('idClient', idClient);
            const response = await fetch(`https://sites.freeboxos.fr/Api/Administratif/updateAccident.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
                Alert.alert('Succès', data.message);
                navigation.navigate('Administratifs');
            } else {
                Alert.alert('Erreur lors de la modification de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la modification de l\'élément:', error.message);
        }
    };

    // Fonction pour supprimer un élément
    const handleDeleteItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idAccident', selectedItem.idAccident);
            const response = await fetch(`https://sites.freeboxos.fr/Api/Administratif/supprAccident.php`, {
                method: 'POST',
                body: formData,
            });
    
            if (response.ok) {
                const data = await response.json();
                navigation.navigate('Administratifs');
                Alert.alert('Succès', data.message);
            } else {
                Alert.alert('Erreur lors de la suppression de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la suppression de l\'élément:', error.message);
        }
    };
    return (
        <ScrollView>
            <Header title="Détails de l'accident" />
            <Text style={styles.title}>Modifier l'élément</Text>
            <Text>ID de l'accident : {selectedItem.idAccident}</Text>
            
            <Text>Numero de Constat:</Text>
            <InputText
                value={NumeroConstat}
                onChangeText={setNumeroConstat}
            />

            <Text> Numéro de client</Text>
            <DropDown
                data={clients}
                onSelect={value => setIdClient(value)}
                placeholder="Sélectionnez un client"
                selectedValue={selectedItem.idClient}
               
            />
               <DropDown
                    data={vehicules}
                    onSelect={value => setSelectedVehicule(value)}
                    placeholder="Sélectionnez un véhicule"
                    selectedValue={selectedVehicule}
                />
            <DropDown
                data={assurances}
                onSelect={value => setIdAssurance(value)}
                placeholder="Sélectionnez une assurance"
                selectedValue={selectedItem.idAssurance}
            />

            <Text> Date de l'accident</Text>
            <InputText
                value={Date}
                onChangeText={setDate}
            />
              <SelectedImageServer uri={selectedItem.imageConstat} />

              <View style={styles.dataContainer}>

            <BouttonConfirme value="Modifier" onPress={handleEditItem} />
            <BouttonConfirme value="Supprimer" onPress={handleDeleteItem} />
            </View>
            <Footer />
        </ScrollView>
    );
};
    const styles = StyleSheet.create({
        title: {
            fontSize: 24,
            fontWeight: 'bold',
            textAlign: 'center',
            marginVertical: 20,
        },
        dataContainer: {
            flexDirection: 'row',
            flexWrap: 'wrap',
            justifyContent: 'center',
          },
      
    });

    export default AccidentDetails;