import React, { useEffect, useState } from 'react';
import { View, StyleSheet, Alert} from 'react-native';
import Header from '../../Components/Header';
import CustomFlatList from '../../Components/CustomFlatList';
import Boutton from '../../Components/Boutton'; 
import Footer from '../../Components/Footer';


const ListeAccidents = ({ navigation }) => {
    const [accidents, setAccidents] = useState([]);
    const [page, setPage] = useState(1);
    const [hasMore, setHasMore] = useState(true);
    const [totalPages, setTotalPages] = useState(0);
    const PageName = ['AccidentDetails'];

    // Récupération des accidents à chaque changement de page
    useEffect(() => {
        fetchlisteAccidents();
    }, [page]);

    // Fonction pour récupérer la liste des accidents
    const fetchlisteAccidents = () => {
        fetch(`https://sites.freeboxos.fr/Api/Administratif/getAccidents.php?page=${page}`)
            .then((response) => response.json())
            .then((json) => {
                if (json.success) {
                    setAccidents(prevAccidents => [...prevAccidents, ...json.accidents]);
                    // Vérifiez si la page actuelle est la dernière page
                    setTotalPages(json.totalPages);
                    setHasMore(page < json.totalPages);
                } else {
                    Alert.alert(json.message || json.error);
                }
            })
            .catch((error) => console.error(error))
    };
    // Fonction pour extraire les clés de l'objet
    const keyExtractor = (item, index) => index.toString();

    // Tableau des titres
    const titles = ["Numéro de l'Accident", 'Numéro du constat', "Client", "Date", "Marque", "Modèle", "Immatriculation", "Image Constat"];
    
    // Fonction pour afficher les éléments de la liste
    const renderItem = ({ item }) => (
        <View>
            {item.idAccident}
            {item.NumeroConstat}
            {item.Date}
            {item.nom_client}
            {item.nom_marque}
            {item.nom_modele}
            {item.Immat}
            { item.imageConstat}
        </View>
    );

    return (
        <View style={styles.container}>
            <Header title="Liste des accidents" />
           

            <CustomFlatList
                data={accidents}
                renderItem={renderItem}
                keyExtractor={keyExtractor}
                titles={titles}
                setPage={setPage}
                selectedKeys={['idAccident', 'NumeroConstat', 'nom_client', 'Date', 'nom_marque', 'nom_modele', 'Immat', 'imageConstat']}
                hasMore={hasMore} // Passer hasMore comme prop
                PageName={PageName}
                navigation={navigation}

             
            />
             <Boutton title="Ajouter un accident" onPress={() => navigation.navigate('AjoutAccident')} value='Ajouter'/>
            <Footer />
        </View>
    );
};

const styles = StyleSheet.create({
    container: {
        flex: 1,
        padding: 20,
    },
 
});
export default ListeAccidents;
