import React, { useState, useEffect } from "react";
import { View,  StyleSheet, ScrollView, Alert } from "react-native";
import Header from "../../Components/Header";
import Boutton from "../../Components/Boutton";
import DropDown from "../../Components/DropDown";
import Footer from "../../Components/Footer";

const AjoutCharge = ({ navigation }) => {
  const [idSupplements, setIdSupplements] = useState("");
  const [idClient, setIdClient] = useState("");
  const [vehicules, setVehicules] = useState([]);
  const [selectedVehicule, setSelectedVehicule] = useState(null);
  const [supplements, setSupplements] = useState([]);
  const [clients, setClients] = useState([]);

 
// Récupération des véhicules, des suppléments et des clients lors du chargement du composant
  useEffect(() => {
    fetchAllVehicules();
    fetchSupplements();
    fetchAllClients();
  }, []);

  // Fonction pour récupérer les suppléments
  const fetchSupplements = async () => {
    try {
      const response = await fetch(
        "https://sites.freeboxos.fr/Api/Listes/getSuplements.php"
      );
      const json = await response.json();
      if (json.success) {
        setSupplements(
          json.charges.map((charge) => ({
            label: `${charge.idSupplements} - ${charge.nom}`,
            value: charge.idSupplements,
          }))
        );
      } else {
        Alert.alert(json.message || json.error);
      }
    } catch (error) {
      Alert.alert("Une erreur est survenue lors de la récupération des suppléments");
    }
  };

  // Fonction pour récupérer tous les clients
  const fetchAllClients = async () => {
    try {
      let allClients = [];
      let currentPage = 1;
      let morePages = true;

      while (morePages) {
        const response = await fetch(
          `https://sites.freeboxos.fr/Api/Clients/getClients.php?page=${currentPage}`
        );
        const json = await response.json();
        if (json.success) {
          allClients = [
            ...allClients,
            ...json.clients.map((client) => ({
              label: `${client.idClient} - ${client.nom}`,
              value: client.idClient,
            })),
          ];
          currentPage++;
          morePages = currentPage <= json.totalPages;
        } else {
          Alert.alert(json.message || json.error);
          break;
        }
      }

      setClients(allClients);
    } catch (error) {
      Alert.alert("Une erreur est survenue lors de la récupération des clients");
    }
  };

  // Fonction pour récupérer les véhicules
  const fetchAllVehicules = async () => {
    try {
      let allVehicules = [];
      let currentPage = 1;
      let morePages = true;

      while (morePages) {
        const response = await fetch(
          `https://sites.freeboxos.fr/Api/Vehicules/getVehicules.php?page=${currentPage}`
        );
        const json = await response.json();
        if (json.success) {
          allVehicules = [
            ...allVehicules,
            ...json.vehicules.map((vehicule) => ({
              label: `${vehicule.nom_marque} - ${vehicule.Immat}`,
              value: vehicule.idVehicule,
            })),
          ];
          currentPage++;
          morePages = currentPage <= json.totalPages;
        } else {
          Alert.alert(json.message || json.error);
          break;
        }
      }

      setVehicules(allVehicules);
    } catch (error) {
      Alert.alert("Une erreur est survenue lors de la récupération des véhicules");
    }
  };

  // Fonction pour ajouter une charge
  const FonctionAjoutCharge = async () => {
    try {
      // Vérifie si les champs sont vides
      if (!selectedVehicule || !idSupplements || !idClient) {
        Alert.alert("Veuillez remplir correctement tous les champs");
        return;
      }

      // construit le formulaire
      const formData = new FormData();
      formData.append("idSupplements", idSupplements);
      formData.append("idVehicule", selectedVehicule);
      formData.append("idClient", idClient);
      // Envoi  la requête
      const response = await fetch(
        "https://sites.freeboxos.fr/Api/Vehicules/insertCharge.php",
        {
          method: "POST",
          body: formData,
        }
      );
      const json = await response.json();
      if (json.success) {
        Alert.alert("Charge ajoutée avec succès");
        setIdSupplements("");
        setSelectedVehicule(null);
        setIdClient("");
        navigation.navigate("Vehicules");
      } else {
        Alert.alert(json.message || json.error);
      }
    } catch (error) {
      Alert.alert("Une erreur est survenue lors de l'ajout de la charge");
    }
  };

  return (
    <ScrollView>
      <View style={styles.container}>
        <Header title="Ajout d'une charge" />

        <DropDown
          data={vehicules}
          onSelect={(value) => setSelectedVehicule(value)}
          placeholder="Sélectionnez un véhicule"
         
        />

        <DropDown
          data={supplements}
          onSelect={(value) => setIdSupplements(value)}
          placeholder="Sélectionnez un supplements"
      
        />

        <DropDown
          data={clients}
          onSelect={(value) => setIdClient(value)}
          placeholder="Sélectionnez un client"
     
        />

        <Boutton
          value="Ajouter la charge"
          onPress={FonctionAjoutCharge}
          style={styles.Boutton}
        />
      </View>
      <Footer />
    </ScrollView>
  );
};

const styles = StyleSheet.create({
  container: {
    padding: 20,
    backgroundColor: "#fff",
  },
});

export default AjoutCharge;
