import React, { useState, useEffect } from 'react';
import { StyleSheet, Alert, ScrollView,View } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native'; 
import DropDown from '../../Components/DropDown';
import Header from '../../Components/Header';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

const ChargeDetails = ({ route }) => {
    const { selectedItem } = route.params;
    const navigation = useNavigation();
    const [idSupplements, setIdSupplements] = useState(selectedItem.idSupplements);
    const[idSupplementsVehicule, setIdSupplementsVehicule] = useState(selectedItem.idSupplementsVehicule);
    const [clients, setClients] = useState([]);
    const [vehicules, setVehicules] = useState([]);
    const [selectedClient, setSelectedClient] = useState(selectedItem.idClient);
    const [selectedVehicule, setSelectedVehicule] = useState(selectedItem.idVehicule);   
    const [charges, setCharges] = useState([]);

    useEffect(() => {
        fetchAllClients();
        fetchAllVehicules();
        fetchCharges();
    }, []);



// Fonction pour récupérer les charges
const fetchCharges = async () => {
    try {
        const response = await fetch('https://sites.freeboxos.fr/Api/Listes/getSuplements.php');
        const json = await response.json();
        if (json.success) {
            const allCharges = json.charges.map(charge => ({
                label: `${charge.nom} - ${charge.frais} ${charge.description}`,
                value: charge.idSupplements
            }));
            setCharges(allCharges);
        } else {
            Alert.alert(json.message || json.error);
        }
    } catch (error) {
        Alert.alert('Une erreur est survenue lors de la récupération des charges');
    }
};


    // Fonction pour récupérer les véhicules
    const fetchAllVehicules = async () => {
        try {
            let allVehicules = [];
            let currentPage = 1;
            let morePages = true;

            while (morePages) {
                const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/getVehicules.php?page=${currentPage}`);
                const json = await response.json();
                if (json.success) {
                    allVehicules = [...allVehicules, ...json.vehicules.map(vehicule => ({ label: `${vehicule.nom_marque} - ${vehicule.Immat}`, value: vehicule.idVehicule }))];
                    currentPage++;
                    morePages = currentPage <= json.totalPages;
                } else {
                    console.error(json.message || json.error);
                    break;
                }
            }

            setVehicules(allVehicules);
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des véhicules.');
        }
    };

    // Fonction pour récupérer tous les clients
    const fetchAllClients = async () => {
        try {
            let allClients = [];
            let currentPage = 1;
            let morePages = true;
    
            while (morePages) {
                const response = await fetch(`https://sites.freeboxos.fr/Api/Clients/getClients.php?page=${currentPage}`);
                const json = await response.json();
                if (json.success) {
                    allClients = [...allClients, ...json.clients.map(client => ({ label: `${client.idClient}  - ${client.Genre} ${client.nom}`, value: client.idClient }))];
                    currentPage++;
                    morePages = currentPage <= json.totalPages;
                } else {
                    console.error(json.message || json.error);
                    break;
                }
            }
    
            setClients(allClients);
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des clients.');
        }
    };

    // Fonction pour modifier un élément
    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idSupplements', idSupplements);
            formData.append('idClient', selectedClient);
            formData.append('idVehicule', selectedVehicule);
            formData.append('idSupplementsVehicule', selectedItem.idSupplementsVehicule);
          
            const response = await fetch('https://sites.freeboxos.fr/Api/Vehicules/updateSuplementsVehicule.php', {
                method: 'POST',
                body: formData,
            });
    
            const json = await response.json();
            if (json.success) {
                Alert.alert('Succès', json.message);
                navigation.navigate("Vehicules");
            } else {
                Alert.alert('Erreur', json.message || json.error);
            }
        } catch (error) {
           Alert.alert('Une erreur est survenue lors de la modification de l\'élément');
        }
    };
   
    // Fonction pour supprimer un élément
    const handleDeleteItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idSupplementsVehicule', selectedItem.idSupplementsVehicule);
    
            const response = await fetch('https://sites.freeboxos.fr/Api/Vehicules/supprSuplementsVehicule.php', {
                method: 'POST',
                body: formData,
            });
    
            const json = await response.json();
            if (json.success) {
                Alert.alert('Succès', json.message);
                navigation.navigate("Vehicules");
            } else {
                Alert.alert('Erreur', json.message || json.error);
            }
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la suppression de l\'élément');
        }
    };
    

    return (
        <ScrollView>
            <Header title="Détails charges" />
            <Text style={styles.title}>Modifier l'élément</Text>
            <Text>ID du supplements du véhicule : {selectedItem.idSupplementsVehicule}</Text>

            <DropDown
                data={charges}
                onSelect={value => setIdSupplements(value)}
                placeholder="Sélectionnez un suppléments"
                selectedValue={selectedItem.idSupplements}
            />
<DropDown
    data={clients}
    onSelect={value => setSelectedClient(value)}
    placeholder="Sélectionnez un client"
    selectedValue={selectedClient}
/>

<DropDown
    data={vehicules}
    onSelect={value => setSelectedVehicule(value)}
    placeholder="Sélectionnez un véhicule"
    selectedValue={selectedVehicule}
/>

<View style={styles.dataContainer}>
            <BouttonConfirme value="Modifier" onPress={handleEditItem} />
            <BouttonConfirme value="Supprimer" onPress={handleDeleteItem} />
        </View>
            <Footer />
        </ScrollView>
    );
}

const styles = StyleSheet.create({
    title: {
        fontSize: 24,
        fontWeight: 'bold',
        textAlign: 'center',
        marginVertical: 20,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
      },
});

export default ChargeDetails;
