import React, { useState, useEffect } from 'react';
import { View, StyleSheet, ScrollView, Alert } from 'react-native';
import Header from '../../Components/Header';
import Boutton from '../../Components/Boutton';
import DropDown from '../../Components/DropDown';
import DatePicker from '../../Components/DatePicker';
import InputText from '../../Components/InputText';
import PhotoSelector from '../../Components/PhotoSelector'; 
import CameraSelector from '../../Components/CameraSelector'; 
import SelectedImage from '../../Components/SelectedImage';
import CheckItem from '../../Components/CheckItem';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

// Fonction pour ajouter un check de véhicule
const AjoutCheckVehicule = ({ navigation }) => {

    const [idClient, setIdClient] = useState('');
    const [vehicules, setVehicules] = useState([]);
    const [selectedVehicule, setSelectedVehicule] = useState(null);
    const [nomDocument, setNomDocument] = useState('');
    const [client, setClients] = useState([]);
    const [CheckIn, setCheckIn] = useState(new Date());
    const [CheckOut, setCheckOut] = useState(new Date());
    const [selectedImage, setSelectedImage] = useState(null);
    const [page, setPage] = useState(1);
    const [airConditionneStatus, setAirConditionneStatus] = useState(null);
    const [pneusStatus, setPneusStatus] = useState(null);
    const [carrosserieStatus, setCarrosserieStatus] = useState(null);
    const [moteurStatus, setMoteurStatus] = useState(null);
    

     // Récupérer les clients et les véhicules lors du chargement du composant
     useEffect(() => {
        fetchAllClients();
        fetchAllVehicules();
    }, []);
    
    // Fonction pour récupérer tous les clients
    const fetchAllClients = async () => {
        try {
            let allClients = [];
            let currentPage = 1;
            let morePages = true;
    
            while (morePages) {
                const response = await fetch(`https://sites.freeboxos.fr/Api/Clients/getClients.php?page=${currentPage}`);
                const json = await response.json();
                if (json.success) {
                    allClients = [...allClients, ...json.clients.map(client => ({ label: `${client.idClient} - ${client.nom}`, value: client.idClient }))];
                    currentPage++;
                    morePages = currentPage <= json.totalPages;
                } else {
                    Alert.alert(json.message || json.error);
                    break;
                }
            }
    
            setClients(allClients);
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des clients');
        }
    };
      // Fonction pour récupérer les véhicules
      const fetchAllVehicules = async () => {
        try {
            let allVehicules = [];
            let currentPage = 1;
            let morePages = true;
    
            while (morePages) {
                const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/getVehicules.php?page=${currentPage}`);
                const json = await response.json();
                if (json.success) {
                    allVehicules = [...allVehicules, ...json.vehicules.map(vehicule => ({ label: `${vehicule.nom_marque} - ${vehicule.Immat}`, value: vehicule.idVehicule }))];
                    currentPage++;
                    morePages = currentPage <= json.totalPages;
                } else {
                    Alert.alert(json.message || json.error);
                    break;
                }
            }
    
            setVehicules(allVehicules);
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des véhicules');
        }
    };

    const FonctionAjoutCheck = async () => {
        // Vérifie si les champs sont vides
        if (!selectedVehicule || !idClient || !CheckIn || !CheckOut || !nomDocument || !selectedImage) {
            Alert.alert('Veuillez remplir correctement tous les champs');
            return;
        }
        if (CheckIn > CheckOut) {
            Alert.alert('La date de CheckIn doit être inférieure à la date de CheckOut');
            return;
        }
    
        const filename = nomDocument.replace(/\s+/g, '_') + '.jpeg'; 
        const localUri = selectedImage;
        const formattedCheckIn = `${CheckIn.getFullYear()}-${('0' + (CheckIn.getMonth() + 1)).slice(-2)}-${('0' + CheckIn.getDate()).slice(-2)} ${('0' + CheckIn.getHours()).slice(-2)}:${('0' + CheckIn.getMinutes()).slice(-2)}:${('0' + CheckIn.getSeconds()).slice(-2)}`;
        const formattedCheckOut = `${CheckOut.getFullYear()}-${('0' + (CheckOut.getMonth() + 1)).slice(-2)}-${('0' + CheckOut.getDate()).slice(-2)} ${('0' + CheckOut.getHours()).slice(-2)}:${('0' + CheckOut.getMinutes()).slice(-2)}:${('0' + CheckOut.getSeconds()).slice(-2)}`;
        
              // Création du formulaire FormData
              const formData = new FormData();
              formData.append('image', { uri: localUri, name: filename + '.jpeg', type: 'image/jpeg' });
              formData.append('idVehicule', selectedVehicule);
              formData.append('idClient', idClient);
              formData.append('checkIn', formattedCheckIn);
              formData.append('checkOut', formattedCheckOut);
              formData.append('nomDocument', nomDocument);
              formData.append('airConditionne', airConditionneStatus);
              formData.append('pneus', pneusStatus);
              formData.append('carrosserie', carrosserieStatus);
              formData.append('moteur', moteurStatus);
         
        try {
            const response = await fetch('https://sites.freeboxos.fr/Api/Vehicules/insertEtat.php', {
                
                method: 'POST',
                body: formData,
            });
            const json = await response.json();
            if (json.success) {
                setSelectedVehicule(null);
                setIdClient('');
                setCheckIn(new Date());
                setCheckOut(new Date());
                setNomDocument('');
                setSelectedImage(null);
                setAirConditionneStatus(null);
                setPneusStatus(null);
                setCarrosserieStatus(null);
                setMoteurStatus(null);
                navigation.navigate("Vehicules");
                Alert.alert('L\'insertion a été faite avec succès.');
            } else {
                Alert.alert(json.message || json.error);
            }
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de l\'insertion.');   
        }
    };
   
    return (
        <ScrollView>
            <View style={styles.container}>
            <Header title="Ajout d'un Check de véhicule" />
                <DropDown
                    data={vehicules}
                    onSelect={value => setSelectedVehicule(value)}
                    placeholder="Sélectionnez un véhicule"
                 
                />
                <DropDown
                    data={client}
                    onSelect={value => setIdClient(value)}
                    placeholder="Sélectionnez un client"
                 
                />

                {/* Date Check In */}
                <View style={styles.formGroup}>
                    <Text style={styles.label}>CheckIn</Text>
                <DatePicker value={CheckIn} onChange={setCheckIn} />
                  
                </View>
                {/* Date check Out */}
                <View style={styles.formGroup}>
                    <Text style={styles.label}>CheckOut</Text>
                <DatePicker value={CheckOut} onChange={setCheckOut} />
                            </View>

                <View style={styles.formGroup}>
                    <Text style={styles.label}>Nom du document</Text>
                    <InputText value={nomDocument} onChangeText={setNomDocument} placeholder="Nom du document" />
                </View>

                <View style={styles.dataContainer}>
                {/* Image  galerie */}  
                <PhotoSelector onSelectImage={setSelectedImage} /> 

                   {/* Image  apareil photo */}
                <CameraSelector onSelectImage={setSelectedImage} /> 
                </View>
                       {/* Afficher l'image sélectionnée si elle existe */}
                {selectedImage && <SelectedImage uri={selectedImage} />}
           
                <CheckItem
  itemName={"Air conditionné"}
  status={airConditionneStatus}
  setStatus={setAirConditionneStatus}
/>
<CheckItem
  itemName={"Pneus"}
  status={pneusStatus}
  setStatus={setPneusStatus}
/>
<CheckItem
  itemName={"Carrosserie"}
  status={carrosserieStatus}
  setStatus={setCarrosserieStatus}
/>
<CheckItem
  itemName={"Moteur"}
  status={moteurStatus}
  setStatus={setMoteurStatus}
/>


                <Boutton value="Ajouter un check " onPress={FonctionAjoutCheck} style={styles.Boutton} />

            </View>
            <Footer />
        </ScrollView>

    );
}
const styles = StyleSheet.create({
    container: {
        padding: 20,
        backgroundColor: '#fff',
    },
    formGroup: {
        marginBottom: 20,
    },
    label: {
        fontSize: 18,
        marginBottom: 5,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
      },

});
export default AjoutCheckVehicule;
