import React, { useState, useEffect } from 'react';
import { StyleSheet, Alert, ScrollView, View } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native'; 
import DropDown from '../../Components/DropDown';
import Header from '../../Components/Header';
import InputText from '../../Components/InputText';
import SelectedImageServer from '../../Components/SelectedImageServeur';
import CheckItem from '../../Components/CheckItem'; 
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

// Fonction pour afficher les détails d'un check de véhicule
const CheckVehiculeDetails = ({ route }) => {
    const { selectedItem } = route.params;
    const [idetat, setIdEtat] = useState(selectedItem.idEtat);
    const [selectedVehicule, setSelectedVehicule] = useState(selectedItem.idVehicule); 
    const [nomDocument, setNomDocument] = useState(selectedItem.nomDocument); 
    const [selectedClient, setSelectedClient] = useState(selectedItem.idClient);
    const [ImageEtat, setImageEtat] = useState(selectedItem.imageEtat);
    const [CheckIn, setCheckIn] = useState(selectedItem.checkIn);
    const [CheckOut, setCheckOut] = useState(selectedItem.checkOut);
    const [pneusStatus, setPneusStatus] = useState(selectedItem.pneusStatus)
    const [airConditionneStatus, setAirConditionneStatus] = useState(selectedItem.airConditionneStatus);
    const [carrosserieStatus, setCarrosserieStatus] = useState(selectedItem.carrosserieStatus);
    const [moteurStatus, setMoteurStatus] = useState(selectedItem.moteurStatus);
    const [vehicules, setVehicules] = useState([]);
    const [clients, setClients] = useState([]);
    const navigation = useNavigation();

    useEffect(() => {
        fetchAllVehicules();
        fetchAllClients();
    }, []);



 // Fonction pour récupérer tous les clients
 const fetchAllClients = async () => {
    try {
        let allClients = [];
        let currentPage = 1;
        let morePages = true;

        while (morePages) {
            const response = await fetch(`https://sites.freeboxos.fr/Api/Clients/getClients.php?page=${currentPage}`);
            const json = await response.json();
            if (json.success) {
                allClients = [...allClients, ...json.clients.map(client => ({ label: `${client.idClient}  - ${client.Genre} ${client.nom}`, value: client.idClient }))];
                currentPage++;
                morePages = currentPage <= json.totalPages;
            } else {
                console.error(json.message || json.error);
                break;
            }
        }

        setClients(allClients);
    } catch (error) {
       Alert.alert('Une erreur est survenue lors de la récupération des clients');
    }
};



    // Fonction pour récupérer les véhicules
    const fetchAllVehicules = async () => {
        try {
            let allVehicules = [];
            let currentPage = 1;
            let morePages = true;

            while (morePages) {
                const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/getVehicules.php?page=${currentPage}`);
                const json = await response.json();
                if (json.success) {
                    allVehicules = [...allVehicules, ...json.vehicules.map(vehicule => ({ label: `${vehicule.nom_marque} - ${vehicule.Immat}`, value: vehicule.idVehicule }))];
                    currentPage++;
                    morePages = currentPage <= json.totalPages;
                } else {
                    console.error(json.message || json.error);
                    break;
                }
            }

            setVehicules(allVehicules);
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des véhicules');
        }
    };


    // Fonction pour modifier un élément
    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idEtat', idetat);
            formData.append('idVehicule', selectedVehicule);
            formData.append('idClient', selectedClient);
            formData.append('CheckIn', CheckIn);
            formData.append('CheckOut', CheckOut);
            formData.append('nomDocument', nomDocument);
            formData.append('pneus', pneusStatus);
            formData.append('airConditionne', airConditionneStatus);
            formData.append('carrosserie', carrosserieStatus);
            formData.append('moteur', moteurStatus);

            const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/updateEtat.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
                Alert.alert('Succès', data.message);
                navigation.navigate("Vehicules");
            } else {
                Alert.alert('Erreur lors de la modification de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la modification de l\'élément:', error.message);
        }
    };

    // Fonction pour supprimer un élément
    const handleDeleteItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idEtat', idetat);
            const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/supprEtat.php`, {
                method: 'POST',
                body: formData,
            });
    
            if (response.ok) {
                const data = await response.json();
                navigation.navigate("Vehicules");
                Alert.alert('Succès', data.message);
            } else {
                Alert.alert('Erreur lors de la suppression de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la suppression de l\'élément:', error.message);
        }
    };

    return (
        <ScrollView>
            <Header title="Détails du Check" />
            <Text style={styles.title}>Modifier l'élément</Text>
            <Text>ID du Check : {idetat}</Text>
      
            <DropDown
                data={vehicules}
                onSelect={value => setSelectedVehicule(value)}
                placeholder="Sélectionnez un véhicule"
                selectedValue={selectedVehicule}
            />
            <DropDown   
                data={clients}
                onSelect={value => setSelectedClient(value)}
                placeholder="Sélectionnez un client"
                selectedValue={selectedClient}
            />
            <Text>CheckIn : </Text>
            <InputText
                value={CheckIn}
                onChangeText={setCheckIn}
            />
           
            <Text>CheckOut : </Text>
            <InputText
                value={CheckOut}
                onChangeText={setCheckOut}
            />

            <Text>Nom : </Text>
            <InputText
                value={nomDocument}
                onChangeText={setNomDocument}
            />

  <CheckItem
  itemName={"Air conditionné"}
  status={airConditionneStatus}
  setStatus={setAirConditionneStatus}
/>
<CheckItem
  itemName={"Pneus"}
  status={pneusStatus}
  setStatus={setPneusStatus}
/>
<CheckItem
  itemName={"Carrosserie"}
  status={carrosserieStatus}
  setStatus={setCarrosserieStatus}
/>
<CheckItem
  itemName={"Moteur"}
  status={moteurStatus}
  setStatus={setMoteurStatus}
/>
      <SelectedImageServer  uri={ImageEtat} />
      <View style={styles.dataContainer}>
            <BouttonConfirme onPress={handleEditItem} value="Enregistrer" />
            <BouttonConfirme onPress={handleDeleteItem} value="Supprimer" />
            </View>
            <Footer />
        </ScrollView>
    );
};

const styles = StyleSheet.create({
    title: {
        fontSize: 24,
        fontWeight: 'bold',
        textAlign: 'center',
        marginVertical: 20,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
      },
  
});

export default CheckVehiculeDetails;
