import React, { useEffect, useState } from 'react';
import { View, StyleSheet, Alert, ScrollView } from 'react-native';
import { emailValidator, nameValidator, firstnameValidator, adresseValidator, villeValidator, cpValidator, telValidator } from '../../core/utils';
import InputText from '../../Components/InputText';
import Boutton from '../../Components/Boutton';
import DropDown from '../../Components/DropDown';
import Header from '../../Components/Header';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

const AjoutClient = ({ navigation }) => {
    
    const [genres, setGenres] = useState([]);
    const [email, setEmail] = useState('');
    const [name, setName] = useState('');
    const [firstname, setFirstname] = useState('');
    const [adresse, setAdresse] = useState('');
    const [ville, setVille] = useState('');
    const [cp, setCp] = useState('');
    const [tel, setTel] = useState('');
    const [selectedGenre, setSelectedGenre] = useState('');
    
 

    // Récupération des genres à chaque chargement du composant
    useEffect(() => {
        fetchGenres();
    }, []);

    // Fetch des genres
    const fetchGenres = async () => {
        try {
            const response = await fetch('https://sites.freeboxos.fr/Api/Listes/getGenre.php');
            const json = await response.json();
            if (json.success) {
                setGenres(json.genres.map(Genre => ({ label: `${Genre.Genre}`, value: Genre.idGenre })));

                
            } else {
                Alert.alert(json.message || json.error);
            }
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des genres');
       
        }
    };

    // Fonction pour l'inscription du client
    const FonctionInscription = async () => {
        try {
            // Validation des champs
            const emailError = emailValidator(email);
            const nameError = nameValidator(name);
            const firstnameError = firstnameValidator(firstname);
            const adresseError = adresseValidator(adresse);
            const villeError = villeValidator(ville);
            const cpError = cpValidator(cp);
            const telError = telValidator(tel);

            if (emailError || firstnameError || nameError || adresseError || villeError || cpError || telError || !selectedGenre) {
                Alert.alert('Veuillez remplir correctement les champs');
                return;
            }

            // Création du formulaire
            const formData = new FormData();
            formData.append("Email", email);
            formData.append("Nom", name);
            formData.append("Prenom", firstname);
            formData.append("Adresse", adresse);
            formData.append("Ville", ville);
            formData.append("CodePostale", cp);
            formData.append("NumeroTelephone", tel);
            formData.append("idGenre", selectedGenre);
    

            // Envoi du formulaire à l'API
            const response = await fetch('https://sites.freeboxos.fr/Api/Clients/insertClients.php', {
                method: 'POST',
                body: formData,
                headers: {
                    "Content-Type": "multipart/form-data"
                },
            });

            const json = await response.json();
            // Si l'inscription est réussie
           
            if (json.success) {
                // Réinitialisation des champs du formulaire
                setEmail('');
                setName('');
                setFirstname('');
                setAdresse('');
                setVille('');
                setCp('');
                setTel('');
                setSelectedGenre('');
               navigation.navigate('Clients');
                Alert.alert ('Client ajouté avec succès');
            } else {
                Alert.alert('L\'e-mail saisi existe déjà. Veuillez saisir une autre adresse mail ou récupérer votre compte');
            }
        } catch (error) {
            Alert.alert('Erreur lors de l\'inscription. Veuillez réessayer.');
        }
    };

    return (
        <ScrollView>
            <Header title="Ajout client" />
            <View style={styles.container}>
                <View style={styles.formGroup}>
                    <Text style={styles.label}>Email</Text>
                    <InputText label="Email" value={email} onChangeText={setEmail} placeholder="Entrez l'adresse mail" />
                </View>
                
        <View style={styles.formGroup}>
                <DropDown
        data={genres}
        onSelect={value => setSelectedGenre(value)}
        placeholder="Sélectionnez une civilité"    
             />
        </View>

               

                <View style={styles.formGroup}>
                    <Text style={styles.label}>Nom</Text>
                    <InputText label="Nom" value={name} onChangeText={setName} placeholder="Entrez le nom" />
                </View>
                <View style={styles.formGroup}>
                    <Text style={styles.label}>Prénom</Text>
                    <InputText label="Prénom" value={firstname} onChangeText={setFirstname} placeholder="Entrez le prénom" />
                </View>
            </View>

            <View style={styles.container2}>
            <View style={styles.formGroup}>
                    <Text style={styles.label}>Adresse</Text>
                    <InputText label="Adresse" value={adresse} onChangeText={setAdresse} placeholder="Entrez l'adresse" />
                </View>
                <View style={styles.formGroup}>
                    <Text style={styles.label}>Ville</Text>
                    <InputText label="Ville" value={ville} onChangeText={setVille}  placeholder="Saisir la ville"/>
                </View>
                <View style={styles.formGroup}>
                    <Text style={styles.label}>Code postal</Text>
                    <InputText label="Code postal" value={cp} onChangeText={setCp} placeholder="code postal" />
                </View>      
                <View style={styles.formGroup}>
                    <Text style={styles.label}>Téléphone</Text>
                    <InputText label="Téléphone" value={tel} onChangeText={setTel} placeholder="Numéro de téléphone" />
            </View>


                </View>

     

<View style={styles.Boutton}>
    <Boutton onPress={FonctionInscription} value="Ajouter client" />
        </View>

            <Footer />
        </ScrollView>
    );
};

const styles = StyleSheet.create({
    container: {
       flex: 1,
        flexDirection: 'row',
        justifyContent: 'space-around',
        paddingHorizontal: 20,
        paddingTop: 20,
      
    },

    container2: {
        flex: 1,
        flexDirection: 'row',
        justifyContent: 'space-around',
        paddingHorizontal: 20,
        paddingTop: 20,
        spaceBetween: 20,   
    },
    container3: {
        flex: 1,
        flexDirection: 'row',
        justifyContent: 'space-around',
        paddingHorizontal: 20,
        paddingTop: 20,
    },
    formGroup: {
        marginBottom: 20,
        width: '25%',
    },
    label: {
        marginBottom: 5,
        fontSize: 16,
    },
 
});

export default AjoutClient;
