import React, { useState, useEffect } from 'react';
import {  StyleSheet, ScrollView , Alert } from 'react-native';
import Boutton from '../../Components/Boutton';
import Header from '../../Components/Header';
import DropDown from '../../Components/DropDown';
import DatePicker from '../../Components/DatePicker';
import InputText from '../../Components/InputText';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

// Fonction pour ajouter un contrat                                                                                                     
const AjoutContrat = ({ navigation }) => {

    const [idVehicule, setIdVehicule] = useState('');
    const [idClient, setIdClient] = useState('');
    const [dateDebut, setDateDebut] = useState(new Date());
    const [dateFin, setDateFin] = useState(new Date());
    const [montantTotal, setMontantTotal] = useState('');
    const [vehicules, setVehicules] = useState([]);
    const [clients, setClients] = useState([]);
    const [selectedVehiculeTarifJour, setSelectedVehiculeTarifJour] = useState(null);
    const [diffInDays, setDiffInDays] = useState(0); 
    
    // Récupérer les clients et les véhicules lors du chargement du composant
    useEffect(() => {
        fetchAllClients();
        fetchAllVehicules();
    }, []);
    
    // Fonction pour récupérer tous les clients
    const fetchAllClients = async () => {
        try {
            let allClients = [];
            let currentPage = 1;
            let morePages = true;
    
            while (morePages) {
                const response = await fetch(`https://sites.freeboxos.fr/Api/Clients/getClients.php?page=${currentPage}`);
                const json = await response.json();
                if (json.success) {
                    allClients = [...allClients, ...json.clients.map(client => ({ label: `${client.idClient} - ${client.nom}`, value: client.idClient }))];
                    currentPage++;
                    morePages = currentPage <= json.totalPages;
                } else {
                    Alert.alert(json.message || json.error);
                    break;
                }
            }
    
            setClients(allClients);
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des clients'); 
        }
    };
    
    // Fonction pour récupérer les véhicules
    const fetchAllVehicules = async () => {
        try {
            let allVehicules = [];
            let currentPage = 1;
            let morePages = true;
    
            while (morePages) {
                const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/getVehicules.php?page=${currentPage}`);
                const json = await response.json();
                if (json.success) {
                    allVehicules = [...allVehicules, ...json.vehicules.map(vehicule => ({ label: `${vehicule.nom_marque} - ${vehicule.Immat}`, value: vehicule.idVehicule, TarifJour: vehicule.TarifJour}))];
                    currentPage++;
                    morePages = currentPage <= json.totalPages;
                } else {
                    Alert.alert(json.message || json.error);
                    break;
                }
            }
    
            setVehicules(allVehicules);
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des véhicules');   
        }
    };

    // Fonction pour calculer le montant total
    const calculerMontantTotal = () => {
        // Assurez-vous que toutes les données nécessaires sont disponibles
        if (idVehicule && dateDebut && dateFin && vehicules.length > 0 && selectedVehiculeTarifJour) {
            // Récupérer le tarif journalier du véhicule sélectionné
            const tarifJournalier = selectedVehiculeTarifJour;

            // Calcul du nombre de jours
            const diffInMs = new Date(dateFin) - new Date(dateDebut);
            const diffInDays = diffInMs / (1000 * 60 * 60 * 24);

            // Calcul du montant total
            const montantTotalCalcule = tarifJournalier * diffInDays;

            // Mise à jour de la valeur de montantTotal avec la valeur calculée
            setMontantTotal(montantTotalCalcule.toString());
        }
    };

   
    useEffect(() => {
        calculerMontantTotal();
    }, [idVehicule, dateDebut, dateFin, selectedVehiculeTarifJour]);

    // Fonction pour ajouter un contrat
    const FonctionAjoutContrat = async () => {
        try {
            // Validation des champs
            if (!idVehicule || !idClient || !dateDebut || !dateFin ) {
                Alert.alert('Veuillez remplir correctement les champs');
                return;
            }
            
        const formattedDateDebut = `${dateDebut.getFullYear()}-${('0' + (dateDebut.getMonth() + 1)).slice(-2)}-${('0' + dateDebut.getDate()).slice(-2)} ${('0' + dateDebut.getHours()).slice(-2)}:${('0' + dateDebut.getMinutes()).slice(-2)}:${('0' + dateDebut.getSeconds()).slice(-2)}`;
        const formattedDateFin = `${dateFin.getFullYear()}-${('0' + (dateFin.getMonth() + 1)).slice(-2)}-${('0' + dateFin.getDate()).slice(-2)} ${('0' + dateFin.getHours()).slice(-2)}:${('0' + dateFin.getMinutes()).slice(-2)}:${('0' + dateFin.getSeconds()).slice(-2)}`;
            // Création du formulaire
            const formData = new FormData();
            formData.append("idVehicule", idVehicule);
            formData.append("idClient", idClient);
            formData.append("dateDebut", formattedDateDebut);
            formData.append("dateFin", formattedDateFin);
            formData.append("montantTotal", montantTotal); // Utilisation du montant total déjà calculé
            formData.append("nombreJours", diffInDays); 

            // Envoi du formulaire à l'API
            const response = await fetch('https://sites.freeboxos.fr/Api/Administratif/insertContrat.php', {
                method: 'POST',
                body: formData,
                headers: {
                    "Content-Type": "multipart/form-data"
                },
            });

            const json = await response.json();
            // Si l'ajout est réussi
            if (json.success) {
                Alert.alert('Contrat ajouté avec succès');
                setIdVehicule('');
                setIdClient('');
                setDateDebut(new Date());
                setDateFin(new Date());
                setMontantTotal('');
                navigation.navigate('Administratifs');
                
            } else {
                Alert.alert(json.message || json.error);
            }
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de l\'ajout du contrat');
        }
    };

    return (
        <ScrollView>
            <Header title="Ajout d'un contrat" />
            
            {/* Véhicule */}
            <DropDown
                data={vehicules}
                onSelect={value => {
                    const selectedValue = Array.isArray(value) ? value[0] : value;
                    const selectedVehicule = vehicules.find(vehicule => vehicule.value === selectedValue);
                    if (selectedVehicule) {
                        setSelectedVehiculeTarifJour(selectedVehicule.TarifJour);
                        setIdVehicule(selectedValue);
                    } else {
                        // Gérer le cas où aucun véhicule n'est trouvé
                        Alert.alert("Aucun véhicule trouvé avec l'ID:", selectedValue);
                    }
                }}
                placeholder="Sélectionnez un véhicule"
        
            />

            {/* Client */}  
            <DropDown
                data={clients}
                onSelect={value => setIdClient(value)}
                placeholder="Sélectionnez un client"
            />

            {/* Date debut */}
            <Text style={styles.label}>Date de début</Text>
            <DatePicker value={dateDebut} onChange={setDateDebut} />
    
            {/* Date Fin */}
            <Text style={styles.label}>Date de fin</Text>
            <DatePicker value={dateFin} onChange={setDateFin} />
        
            {/* Montant total */}
            <Text style={styles.label}>Montant total</Text>
            <InputText
    value={`${montantTotal} €`}
    onChangeText={text => {
        // Assurez-vous de filtrer le texte pour ne garder que les chiffres
        const numericValue = text.replace(/[^0-9.]/g, '');
        setMontantTotal(numericValue);
    }}
/>

            <Boutton value="Ajouter le contrat" onPress={FonctionAjoutContrat} />
            <Footer />
        </ScrollView> 
    );
}

const styles = StyleSheet.create({
    container: {
        padding: 20,
        backgroundColor: '#fff',
    },
    formGroup: {
        marginBottom: 20,
    },
    label: {
        fontSize: 18,
        marginBottom: 5,
    },
});

export default AjoutContrat;
