import React, { useState, useEffect } from 'react';
import { View, StyleSheet, Alert, ScrollView } from 'react-native';
import InputText from '../../Components/InputText';
import Boutton from '../../Components/Boutton';
import Header from '../../Components/Header';
import DropDown from '../../Components/DropDown';
import DatePicker from '../../Components/DatePicker';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

// Fonction pour ajouter un controle technique
const AjoutControle = ({ navigation }) => {
    const [nomControleTechnique, setNomControleTechnique] = useState('');
    const [numeroControle, setNumeroControle] = useState('');
    const [fraisControle, setFraisControle] = useState('');
    const [contact, setContact] = useState('');
    const [selectedVehicule, setSelectedVehicule] = useState(null);
    const [vehicules, setVehicules] = useState([]);
    const [dateExpiration, setDateExpiration] = useState(new Date()); 
   

     // Fonction pour récupérer les véhicules
     useEffect(() => {
        fetchAllVehicules();
    }, []);
    
    // Fonction pour récupérer les véhicules
    const fetchAllVehicules = async () => {
        try {
            let allVehicules = [];
            let currentPage = 1;
            let morePages = true;
    
            while (morePages) {
                const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/getVehicules.php?page=${currentPage}`);
                const json = await response.json();
                if (json.success) {
                    allVehicules = [...allVehicules, ...json.vehicules.map(vehicule => ({ label: `${vehicule.nom_marque} - ${vehicule.Immat}`, value: vehicule.idVehicule }))];
                    currentPage++;
                    morePages = currentPage <= json.totalPages;
                } else {
                    Alert.alert(json.message || json.error);
                    break;
                }
            }
    
            setVehicules(allVehicules);
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des véhicules');
        }
    };
    
 // Fonction pour ajouter un controle technique
    const FonctionAjoutControle = async () => {
        const formattedDateExpiration = `${dateExpiration.getFullYear()}-${('0' + (dateExpiration.getMonth() + 1)).slice(-2)}-${('0' + dateExpiration.getDate()).slice(-2)}`;
        try {
            // Validation des champs
            if (!nomControleTechnique || !dateExpiration || !numeroControle || !fraisControle || !contact || !selectedVehicule) {
                Alert.alert('Veuillez remplir correctement les champs');
                return;
            }

            // Création du formulaire
            const formData = new FormData();
            formData.append("nomControleTechnique", nomControleTechnique);
            formData.append("dateExpiration", formattedDateExpiration);
            formData.append("numeroControle", numeroControle);
            formData.append("fraisControle", fraisControle);
            formData.append("contact", contact);
            formData.append("selectedVehicule", selectedVehicule);
                   
            // Envoi du formulaire à l'API
            const response = await fetch('https://sites.freeboxos.fr/Api/Administratif/insertControle.php', {
                method: 'POST',
                body: formData,
                headers: {
                    "Content-Type": "multipart/form-data"
                },
            });

            const json = await response.json();
            // Si l'ajout est réussi
            if (json.success) {
                // Réinitialisation des champs du formulaire
                setNomControleTechnique('');
                setDateExpiration(new Date()); // Réinitialiser la date d'expiration à la date actuelle
                setNumeroControle('');
                setFraisControle('');
                setContact('');
                setSelectedVehicule(null);
                navigation.navigate('Administratifs');
                Alert.alert('Le controle technique a été ajoutée avec succès.');
            } else {
                Alert.alert('Erreur lors de l\'ajout du controle technqiue. Veuillez réessayer.');
            }
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de l\'ajout du controle technique.');
        }
    };

    return (
        <ScrollView contentContainerStyle={styles.container}>
            <Header title="Ajout de controle Technique" />

            {/* Sélection du véhicule */}
            <DropDown
                data={vehicules}
                onSelect={value => setSelectedVehicule(value)}
                placeholder="Sélectionnez un véhicule"
            />

            {/* Nom de l'entreprise effectuant le controle technique */}
            <View style={styles.formGroup}>
                <Text style={styles.label}>Nom de l'entreprise effectuant le controle technique </Text>
                <InputText value={nomControleTechnique} onChangeText={setNomControleTechnique} placeholder="Nom de l'entreprise effectuant le controle technique" />
            </View>
            
            {/* Date d'expiration */}
          <View style={styles.formGroup}>
                <Text style={styles.label}>dateExpiration</Text>
                <DatePicker value={dateExpiration} onChange={setDateExpiration} />
            </View>

            <View style={styles.formGroup}>
                <Text style={styles.label}>Numéro du controle technique</Text>
                <InputText value={numeroControle} onChangeText={setNumeroControle} placeholder="Numéro du controle technique" />
            </View>
            <View style={styles.formGroup}>
                <Text style={styles.label}>Frais du controle technique</Text>
               <InputText
    value={`${fraisControle} €`}
    onChangeText={text => {
        // Assurez-vous de filtrer le texte pour ne garder que les chiffres
        const numericValue = text.replace(/[^0-9.]/g, '');
        setFraisControle(numericValue);
    }}
/>

            </View>
            <View style={styles.formGroup}>
                <Text style={styles.label}>Contact</Text>
                <InputText value={contact} onChangeText={setContact} placeholder="Contact" />
            </View>

          
            <Boutton value="Ajouter le controle technique" onPress={FonctionAjoutControle} style={styles.Boutton} />
            <Footer />
        </ScrollView>
    );
}

const styles = StyleSheet.create({
    container: {
        padding: 20,
        backgroundColor: '#fff',
    },
    formGroup: {
        marginBottom: 20,
    },
    label: {
        fontSize: 18,
        marginBottom: 5,
    },

});

export default AjoutControle;
