import React, { useState, useEffect } from 'react';
import { StyleSheet, Alert,  ScrollView,View } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native';
import DropDown from '../../Components/DropDown';
import Header from '../../Components/Header';
import InputText from '../../Components/InputText';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

// Fonction pour afficher les détails d'un controle
const ControleDetails = ({ route }) => {
    const { selectedItem } = route.params;
    const [idControle, setIdControle] = useState(selectedItem.idControleTechnique || '');
    const [NumeroControle, setNumeroControle] = useState(selectedItem.NumeroControle);
    const [dateExpiration, setDateExpiration] = useState(selectedItem.dateExpiration);
    const [idVehicule, setIdVehicule] = useState(selectedItem.idVehicule);
    const navigation = useNavigation();
    const [vehicules, setVehicules] = useState([]); 
  const [selectedVehicule, setSelectedVehicule] = useState(selectedItem.idVehicule);
  const [fraisControle, setFraisControle] = useState(selectedItem.fraisControle);
  const [contact, setContact] = useState(selectedItem.contact);
    const [nomControle, setNomControleTechnique] = useState(selectedItem.nomControleTechnique);

    useEffect(() => {
        fetchAllVehicules();
    }, []);


   // Fonction pour récupérer les véhicules
   const fetchAllVehicules = async () => {
    try {
        let allVehicules = [];
        let currentPage = 1;
        let morePages = true;

        while (morePages) {
            const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/getVehicules.php?page=${currentPage}`);
            const json = await response.json();
            if (json.success) {
                allVehicules = [...allVehicules, ...json.vehicules.map(vehicule => ({ label: `${vehicule.nom_marque} - ${vehicule.Immat}`, value: vehicule.idVehicule }))];
                currentPage++;
                morePages = currentPage <= json.totalPages;
            } else {
                Alert.alert(json.message || json.error);
                break;
            }
        }

        setVehicules(allVehicules);
    } catch (error) {
        Alert.alert('Une erreur est survenue lors de la récupération des véhicules');
    }
};


// Fonction pour modifier un élément
    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idControleTechnique', selectedItem.idControleTechnique);
            formData.append('NumeroControle', NumeroControle);
            formData.append('dateExpiration', dateExpiration);
            formData.append('contact', contact);
            formData.append('idVehicule', idVehicule);
            formData.append('fraisControle', fraisControle);
            formData.append('nomControleTechnique', nomControle);
         
            const response = await fetch(`https://sites.freeboxos.fr/Api/Administratif/updateControle.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
                Alert.alert('Succès', data.message);
                navigation.navigate('Administratifs');
            } else {
                Alert.alert('Erreur lors de la modification de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la modification de l\'élément:', error.message);
        }
    };

    // Fonction pour supprimer un élément
    const handleDeleteItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idControleTechnique', selectedItem.idControleTechnique);
            const response = await fetch(`https://sites.freeboxos.fr/Api/Administratif/supprControle.php`, {
                method: 'POST',
                body: formData,
            });
    
            if (response.ok) {
                const data = await response.json();
                navigation.navigate('Administratifs');
                Alert.alert('Succès', data.message);
            } else {
                Alert.alert('Erreur lors de la suppression de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la suppression de l\'élément:', error.message);
        }
    };
    return (
        <ScrollView>
            <Header title="Détails du controle" />
            <Text style={styles.title}>Modifier l'élément</Text>
            <Text>ID du controle : {idControle}</Text>
            
            <Text>Numero de Controle:</Text>
            <InputText
                style={styles.input}
                value={NumeroControle}
                onChangeText={setNumeroControle}
            />

               <DropDown
                    data={vehicules}
                    onSelect={value => setSelectedVehicule(value)}
                    placeholder="Sélectionnez un véhicule"
                    selectedValue={selectedVehicule}
                />
      

            <Text> Date du controle :</Text>
            <InputText
           
                value={dateExpiration}
                onChangeText={setDateExpiration}
            />
           
           <Text> Frais du controle :</Text>
           <InputText
    value={`${fraisControle} €`}
    onChangeText={text => {
        // Assurez-vous de filtrer le texte pour ne garder que les chiffres
        const numericValue = text.replace(/[^0-9.]/g, '');
        setFraisControle(numericValue);
    }}
/>
            <Text> Contact :</Text>
            <InputText
              
                value={contact}
                onChangeText={setContact}
            />
            <Text> Nom controle :</Text>
            <InputText
           
                value={nomControle}
                onChangeText={setNomControleTechnique}
            />
         <View style={styles.dataContainer}>
            <BouttonConfirme value="Modifier" onPress={handleEditItem} />
            <BouttonConfirme value="Supprimer" onPress={handleDeleteItem} />
            </View>
            <Footer />
        </ScrollView>
    );
};
    const styles = StyleSheet.create({
        title: {
            fontSize: 24,
            fontWeight: 'bold',
            textAlign: 'center',
            marginVertical: 20,
        },
        dataContainer: {
            flexDirection: 'row',
            flexWrap: 'wrap',
            justifyContent: 'center',
        },
       
    });

    export default ControleDetails;