import React, { useEffect, useState } from 'react';
import { View, StyleSheet, Alert, ScrollView } from 'react-native';
import InputText from '../../Components/InputText';
import Boutton from '../../Components/Boutton';
import Header from '../../Components/Header';
import PhotoSelector from '../../Components/PhotoSelector'; 
import CameraSelector from '../../Components/CameraSelector'; 
import SelectedImage from '../../Components/SelectedImage';
import DropDown from '../../Components/DropDown';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

// Fonction pour ajouter un document client
const AjoutClientDocuments = ({ navigation }) => {
    const [clients, setClients] = useState([]);
    const [NomDocumentClient, setNomDocumentClient] = useState('');
    const [selectedClient, setSelectedClient] = useState('');
    const [selectedImage, setSelectedImage] = useState(null);

    // Récupérer les clients lors du chargement du composant
    useEffect(() => {
        fetchAllClients();
      }, []);
    
      // Fonction pour récupérer tous les clients
      const fetchAllClients = async () => {
        try {
          let allClients = [];
          let currentPage = 1;
          let morePages = true;
    
          while (morePages) {
            const response = await fetch(`https://sites.freeboxos.fr/Api/Clients/getClients.php?page=${currentPage}`);
            const json = await response.json();
            if (json.success) {
              allClients = [
                ...allClients,
                ...json.clients.map((client) => ({
                  label: `${client.idClient} - ${client.nom}`,
                  value: client.idClient,
                })),
              ];
              currentPage++;
              morePages = currentPage <= json.totalPages;
            } else {
              Alert.alert(json.message || json.error);
              break;
            }
          }
    
          setClients(allClients);
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des clients');
        }
      };
  
// Fonction pour valider l'ajout d'un document client
    const validateImage = async () => {
        if (selectedImage && selectedClient && NomDocumentClient) {
            const localUri = selectedImage; // Obtenez l'URI de l'image
            const filename = NomDocumentClient.replace(/\s+/g, '_') + '.jpeg'; // Utilise le nom du document comme nom de fichier avec une extension
            const formData = new FormData();
            formData.append('image', { uri: localUri, name: filename, type: 'image/jpeg' }); // Ajouter l'image à FormData
            formData.append('idClient', selectedClient); // Ajouter l'id du client à FormData
            formData.append('NomDocumentClient', NomDocumentClient); // Ajouter le nom du document à FormData
         
       
            try {
                const response = await fetch('https://sites.freeboxos.fr/Api/Clients/insertDocsClient.php', {
                    method: 'POST',
                    body: formData,
                    headers: {
                        'Content-Type': 'multipart/form-data',
                    },
                });
                const data = await response.json();
                setNomDocumentClient('');
                setSelectedImage(null);
                setSelectedClient('');
                navigation.navigate('Clients');
                Alert.alert('Succès', 'Le document a été ajouté avec succès.');
    
            } catch (error) {
                Alert.alert('Erreur lors de l\'envoi de l\'image à l\'API :', error);
            }
        } else {
            Alert.alert('Données manquantes', 'Veuillez sélectionner un client, saisir un nom de document et choisir une image avant de valider.');
        }
    };

    return (
        <ScrollView>
            <Header title="Ajout des documents client" />
            <View style={styles.container}>
                
            <DropDown
                    data={clients}
                    onSelect={value => setSelectedClient(value)}
                    placeholder="Sélectionnez un client"       
                />

                <View style={styles.formGroup}>
                    <Text style={styles.label}>Nom du document:</Text>
                    <InputText label="Nom du document" value={NomDocumentClient} onChangeText={setNomDocumentClient} />
                </View>
                <View style={styles.dataContainer}>
                {/* Image  galerie */}  
                <PhotoSelector onSelectImage={setSelectedImage} /> 

                    {/* Image  apareil photo */}
                <CameraSelector onSelectImage={setSelectedImage} /> 

                    {/* Afficher l'image sélectionnée si elle existe */}
                    {selectedImage && <SelectedImage uri={selectedImage} />}
                    <Boutton  onPress={validateImage} value="envoyer" />
                </View>
            </View>
            <Footer />
        </ScrollView>
    );
};

const styles = StyleSheet.create({
    container: {
        flex: 1,
        paddingHorizontal: 20,
        paddingTop: 20,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
    },
    formGroup: {
        marginBottom: 20,
    },
    label: {
        marginBottom: 5,
        fontSize: 16,
    },
   
    
});

export default AjoutClientDocuments;
