import React, { useEffect, useState } from 'react';
import {View,  StyleSheet, Alert} from 'react-native';
import Header from '../../Components/Header';
import CustomFlatList from '../../Components/CustomFlatList';  
import Boutton from '../../Components/Boutton';
import Footer from '../../Components/Footer';

// Fonction pour afficher la liste des factures
const ListeFacture = ({navigation}) => {
    const [factures, setFactures]= useState([]);
    const [page, setPage] = useState(1);
    const [hasMore, setHasMore] = useState(true);
    const [totalPages, setTotalPages] = useState(0);
    const PageName = ['FactureDetails'];

    // Récupérer les factures lors du chargement du composant
    useEffect(() => {
        fetchFactures();
    }, [page]);
        
    // Fonction pour récupérer les factures
     const fetchFactures = () => {   
        
        fetch(`https://sites.freeboxos.fr/Api/Administratif/getFactures.php?page=${page}`)
        .then((response) => response.json())
        .then((json) => {
            if (json.success) {
                setFactures(prevFactures=> [...prevFactures, ...json.factures]);
                setTotalPages(json.totalPages);
                setHasMore(page < json.totalPages);
             
            } else {
                Alert.alert(json.message || json.error);
            }
        })
        .catch((error) => console.error(error))
    };

// Fonction pour afficher la liste des factures
    const keyExtractor = (item, index) => index.toString();
    const titles = ["Numero de la facture",  "Numéro Client","Nom du client", "Date de la facture", "Montant Total"];

    const renderItem = ({ item }) => (
        <View>
            {item.idFacture}
            {item.idClient}
            {item.nom_client}
            {item.DateFacturation}
            {item.Montant}
        </View>
    );


 
    return (
        <View style={styles.container}>
            <Header title="Liste des factures " />
          
                
         
                <CustomFlatList
                    data={factures}
                    renderItem={renderItem}
                    keyExtractor={keyExtractor}
                    titles={titles}
                    setPage={setPage}
                    selectedKeys={['idFacture', 'idClient','nom_client', 'DateFacturation', 'Montant']}
                    hasMore={hasMore}
                    PageName={PageName}
                    navigation={navigation}
                />
                 <Boutton title="Ajouter une facture" onPress={() => navigation.navigate('AjoutFacture')} value='Ajouter' />
            <Footer />
        </View>
    );
};

const styles = StyleSheet.create({
    container: {
        flex: 1,
        padding: 20,
    },
 
});

export default ListeFacture; 