import React, { useState } from 'react';
import { View, StyleSheet, Alert } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native'; // Importer useNavigation
import InputText from '../../Components/InputText';
import Text from '../../Components/Text';
import Header from '../../Components/Header';
import Footer from '../../Components/Footer';

const ModeleDetails = ({ route }) => {
    const selectedItem = route?.params?.selectedItem || {}; 
    const [editedModele, setEditedModele] = useState(selectedItem.nom_Modele);
    const [idModele, setIdModele] = useState(selectedItem.idModele); 
    const navigation = useNavigation(); 

    // Fonction pour modifier un élément
    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idModele', idModele);
            formData.append('nom', editedModele);
         
      
            const response = await fetch(`https://sites.freeboxos.fr/Api/Listes/updateModele.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
                navigation.navigate('Listes'); 
                Alert.alert('Succès', data.message);
                
            } else {
                Alert.alert('Erreur lors de la modification de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la modification de l\'élément:', error.message);
        }
    };

    // Fonction pour supprimer un élément
   const handleDeleteItem = async () => {
    try {
        const formData = new FormData();
        formData.append('idModele', selectedItem.idModele);

        const response = await fetch(`https://sites.freeboxos.fr/Api/Listes/supprModele.php`, {
            method: 'POST',
            body: formData,
        });

        if (response.ok) {
            const data = await response.json();
            navigation.navigate('Listes'); 
            Alert.alert('Succès', data.message);
        } else {
            const errorData = await response.json();
            if (errorData.error.includes('Impossible de supprimer le modèle car il est utilisé dans la table des véhicules')) {
              
                Alert.alert('Erreur', errorData.error);
            } else {
         
                Alert.alert('Erreur lors de la suppression de l\'élément:', errorData.error);
            }
        }
    } catch (error) {
        Alert.alert('Erreur lors de la suppression de l\'élément:', error.message);
    }
};
    return (
        <View>
            <Header title="Détails du modèle" />
            <Text style={styles.title}>Modifier l'élément</Text>
            <Text>ID du modèle: {selectedItem.idModele}</Text>
            <InputText
                value={editedModele}
                onChangeText={setEditedModele}
            />
              <View style={styles.dataContainer}>
            <BouttonConfirme onPress={handleEditItem} value="Enregistrer" />
            <BouttonConfirme onPress={handleDeleteItem} value="Supprimer" />
            </View>
            <Footer />
        </View>
    );
};

const styles = StyleSheet.create({
    title: {
        fontSize: 24,
        fontWeight: 'bold',
        textAlign: 'center',
        marginVertical: 20,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
    },
   
});

export default ModeleDetails;
