import React, { useEffect, useState } from 'react';
import { View, StyleSheet, Alert, ScrollView } from 'react-native'; 
import Boutton from '../../Components/Boutton';
import Header from '../../Components/Header';
import PhotoSelector from '../../Components/PhotoSelector'; 
import CameraSelector from '../../Components/CameraSelector'; 
import SelectedImage from '../../Components/SelectedImage';
import DropDown from '../../Components/DropDown';
import InputText from '../../Components/InputText';
import Text from '../../Components/Text';
import Footer from '../../Components/Footer';

// Fonction pour ajouter une photo de véhicule
const AjoutPhotosVehicule = ({ navigation }) => {
    const [vehicules, setVehicules] = useState([]);
    const [selectedVehicule, setSelectedVehicule] = useState('');
    const [selectedImage, setSelectedImage] = useState(null);
    const [nomPhoto, setNomPhoto] = useState(''); 
 
    
    // Récupérer les véhicules lors du chargement du composant
    useEffect(() => {
        fetchAllVehicules();
    }, []);
    
    // Fonction pour récupérer les véhicules
    const fetchAllVehicules = async () => {
        try {
            let allVehicules = [];
            let currentPage = 1;
            let morePages = true;
    
            while (morePages) {
                const response = await fetch(`https://sites.freeboxos.fr/Api/Vehicules/getVehicules.php?page=${currentPage}`);
                const json = await response.json();
                if (json.success) {
                    allVehicules = [...allVehicules, ...json.vehicules.map(vehicule => ({ label: `${vehicule.nom_marque} -${vehicule.nom_modele}- ${vehicule.Immat}`, value: vehicule.idVehicule }))];
                    currentPage++;
                    morePages = currentPage <= json.totalPages;
                } else {
                Alert.alert(json.message || json.error);
                    break;
                }
            }
    
            setVehicules(allVehicules);
        } catch (error) {
            Alert.alert('Une erreur est survenue lors de la récupération des véhicules');
        }
    };
    
  
// Fonction pour valider l'envoi de l'image
const validateImage = async () => {
    if (selectedImage && selectedVehicule.length > 0 && nomPhoto) {
        const localUri = selectedImage; 
        const filename = nomPhoto.replace(/\s+/g, '_') + '.jpeg'; 
        const formData = new FormData();
        formData.append('image', { uri: localUri, name: filename, type: 'image/jpeg' }); 
        formData.append('idVehicule', selectedVehicule); 
        formData.append('nomPhoto', nomPhoto);   
        try {
            const response = await fetch('https://sites.freeboxos.fr/Api/Vehicules/insertPhotosVehicule.php', {
                method: 'POST',
                body: formData,
                headers: {
                    'Content-Type': 'multipart/form-data',
                },
            });
            const data = await response.json();
            console.log('Réponse de l\'API :', data);
            setNomPhoto('');
            setSelectedImage(null);
            setSelectedVehicule('');
           
            Alert.alert('Photo ajoutée avec succès');
            navigation.navigate('Listes'); 
        } catch (error) {
            Alert.alert('Erreur lors de l\'envoi de l\'image à l\'API :', error);
        }
    } else {
        Alert.alert('Données manquantes', 'Veuillez sélectionner un véhicule, choisir une image et entrer un nom de photo avant de valider.');
    }
};

    
    return (
        <ScrollView>
            <Header title="Ajout photos Véhicule" />
            <View style={styles.container}>
           
            <DropDown
                    data={vehicules}
                    onSelect={(value) => {
                        setSelectedVehicule(value);
                
                    }}
                    placeholder="Sélectionnez un véhicule"
                    
                />

                    {/* Champ d'entrée texte pour saisir le nom de la photo */}
                <Text>Nom de la photo</Text>
                      <InputText label="Nom du document" value={nomPhoto} onChangeText={setNomPhoto} />
            
                      <View style={styles.dataContainer}>
                {/* Image  galerie */}  
                <PhotoSelector onSelectImage={setSelectedImage} /> 

                   {/* Image  apareil photo */}
                <CameraSelector onSelectImage={setSelectedImage} /> 

                       {/* Afficher l'image sélectionnée si elle existe */}
                {selectedImage && <SelectedImage uri={selectedImage} />}
                    <Boutton  onPress={validateImage} value="envoyer" />
                    </View>
            
            </View>
            <Footer />
        </ScrollView>
    );
};

const styles = StyleSheet.create({
    container: {
        flex: 1,
        paddingHorizontal: 20,
        paddingTop: 20,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
    },
   
    
});

export default AjoutPhotosVehicule;
