import React, { useState } from 'react';
import { View, StyleSheet, Alert } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native'; 
import InputText from '../../Components/InputText';
import Text from '../../Components/Text';
import Header from '../../Components/Header';
import Footer from '../../Components/Footer';

// Fonction pour afficher les détails d'un statut
const StatutDetails = ({ route }) => {
    const selectedItem = route?.params?.selectedItem || {}; 
    const [editedStatut, setEditedStatut] = useState(selectedItem.Statut);
    const navigation = useNavigation(); 


    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idStatut', selectedItem.idStatut);
            formData.append('Statut', editedStatut);
            const response = await fetch(`https://sites.freeboxos.fr/Api/Listes/updateStatut.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
                Alert.alert('Succès', data.message);
                navigation.navigate('Listes'); 
            } else {
                Alert.alert('Erreur lors de la modification de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la modification de l\'élément:', error.message);
        }
    };

    //fonction pour supprimer un statut
   const handleDeleteItem = async () => {
    try {
        const formData = new FormData();
        formData.append('idStatut', selectedItem.idStatut);

        const response = await fetch(`https://sites.freeboxos.fr/Api/Listes/supprStatut.php`, {
            method: 'POST',
            body: formData,
        });

        if (response.ok) {
            const data = await response.json();
            navigation.navigate('Listes'); 
            Alert.alert('Succès', data.message);
        } else {
            const errorData = await response.json(); 
            if (errorData.error.includes('Impossible de supprimer le modèle car il est utilisé dans la table des véhicules')) {
              
                Alert.alert('Erreur', errorData.error);
            } else {
         
                Alert.alert('Erreur lors de la suppression de l\'élément:', errorData.error);
            }
        }
    } catch (error) {
        Alert.alert('Erreur lors de la suppression de l\'élément:', error.message);
    }
};
    return (
        <View>
            <Header title="Détails du statut" />
            <Text style={styles.title}>Modifier l'élément</Text>
            <Text>ID du statut: {selectedItem.idStatut}</Text>
            <InputText
                value={editedStatut}
                onChangeText={setEditedStatut}
            />
             <View style={styles.dataContainer}>
            <BouttonConfirme onPress={handleEditItem} value="Enregistrer" />
            <BouttonConfirme onPress={handleDeleteItem} value="Supprimer" />
            </View>
            <Footer />
        </View>
    );
};

const styles = StyleSheet.create({
    title: {
        fontSize: 24,
        fontWeight: 'bold',
        textAlign: 'center',
        marginVertical: 20,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
    },
   
   
});

export default StatutDetails;
