import React, { useState } from 'react';
import { StyleSheet, Alert,ScrollView, View } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native'; // Importer useNavigation
import InputText from '../../Components/InputText';
import Text from '../../Components/Text';
import Header from '../../Components/Header';
import Footer from '../../Components/Footer';

// Fonction pour afficher les détails d'un supplément
const SupplementsDetails = ({ route }) => {
    const selectedItem = route?.params?.selectedItem || {}; 
    const [idSupplements, setIdSupplements] = useState(selectedItem.idSupplements);
    const [editedfrais, setEditedfrais] = useState(selectedItem.frais);
    const [editeddescription, setEditedDescription] = useState(selectedItem.description);
    const [editednom, setEditednom] = useState(selectedItem.nom);
    const navigation = useNavigation(); 

// Fonction pour modifier un supplément
    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idSupplements', selectedItem.idSupplements);
            formData.append('frais', editedfrais);
            formData.append('description', editeddescription);
            formData.append('nom', editednom);

            const response = await fetch(`https://sites.freeboxos.fr/Api/Listes/updateSuplements.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
                
                Alert.alert('Succès', data.message);
                navigation.navigate('Listes'); 
            } else {
                Alert.alert('Erreur lors de la modification de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la modification de l\'élément:', error.message);
        }
    };

    // Fonction pour supprimer un supplément
   const handleDeleteItem = async () => {
    try {
        const formData = new FormData();
        formData.append('idSupplements', selectedItem.idSupplements);

        const response = await fetch(`https://sites.freeboxos.fr/Api/Listes/supprSuplements.php`, {
            method: 'POST',
            body: formData,
        });

        if (response.ok) {
            const data = await response.json();
            navigation.navigate('Listes'); 
            Alert.alert('Succès', data.message);
        } else {
            const errorData = await response.json(); 
            if (errorData.error.includes('Impossible de supprimer le modèle car il est utilisé dans la table des véhicules')) {
              
                Alert.alert('Erreur', errorData.error);
            } else {
         
                Alert.alert('Erreur lors de la suppression de l\'élément:', errorData.error);
            }
        }
    } catch (error) {
        Alert.alert('Erreur lors de la suppression de l\'élément:', error.message);
    }
};
    return (
        <ScrollView>
        
            <Header title="Détails du supplément" />
           
            <Text style={styles.title}>Modifier l'élément</Text>
            <Text>ID du supplément: {selectedItem.idSupplements}</Text>
            <Text>Supplements:</Text>
            <InputText
                value={editednom}
                onChangeText={setEditednom}
            />
            <Text>Frais:</Text>
            <InputText
    value={`${editedfrais} €`}
    onChangeText={text => {
        // Assurez-vous de filtrer le texte pour ne garder que les chiffres
        const numericValue = text.replace(/[^0-9.]/g, '');
        setEditedfrais(numericValue);
    }}
/>
            <Text>Description:</Text>
            <InputText
                value={editeddescription}
                onChangeText={setEditedDescription}
            />
               <View style={styles.dataContainer}>
            <BouttonConfirme onPress={handleEditItem} value="Enregistrer" />
            <BouttonConfirme onPress={handleDeleteItem} value="Supprimer" />
          </View>
        <Footer />
        </ScrollView>
    );
};

const styles = StyleSheet.create({
    title: {
        fontSize: 24,
        fontWeight: 'bold',
        textAlign: 'center',
        marginVertical: 20,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
    },
   
});

export default SupplementsDetails;
