import React, { useState } from 'react';
import { View, Text, StyleSheet, Alert } from 'react-native';
import BouttonConfirme from '../../Components/BouttonConfirme';
import { useNavigation } from '@react-navigation/native'; // Importer useNavigation
import InputText from '../../Components/InputText';
import Header from '../../Components/Header';
import Footer from '../../Components/Footer';

// Fonction pour afficher les détails du type de véhicule
const TypeVehiculeDetails = ({ route }) => {
    const selectedItem = route?.params?.selectedItem || {}; 
    const [editedTypeVehicule, setEditedTypeVehicule] = useState(selectedItem.nomType);
    const navigation = useNavigation(); 

// Fonction pour modifier un type de véhicule
    const handleEditItem = async () => {
        try {
            const formData = new FormData();
            formData.append('idTypeVehicule', selectedItem.idTypeVehicule);
            formData.append('nomType', editedTypeVehicule);
      
            const response = await fetch(`https://sites.freeboxos.fr/Api/Listes/updateTypeVehicule.php`, {
                method: 'POST',
                body: formData,
            });

            if (response.ok) {
                const data = await response.json();
               
                Alert.alert('Succès', data.message);
                navigation.navigate('Listes'); 
            } else {
                Alert.alert('Erreur lors de la modification de l\'élément:', response.statusText);
            }
        } catch (error) {
            Alert.alert('Erreur lors de la modification de l\'élément:', error.message);
        }
    };

    // Fonction pour supprimer un type de véhicule
   const handleDeleteItem = async () => {
    try {
        const formData = new FormData();
        formData.append('idTypeVehicule', selectedItem.idTypeVehicule);

        const response = await fetch(`https://sites.freeboxos.fr/Api/Listes/supprTypeVehicule.php`, {
            method: 'POST',
            body: formData,
        });

        if (response.ok) {
            const data = await response.json();
            navigation.navigate('Listes'); 
            Alert.alert('Succès', data.message);
        } else {
            const errorData = await response.json(); 
            if (errorData.error.includes('Impossible de supprimer le modèle car il est utilisé dans la table des véhicules')) {
              
                Alert.alert('Erreur', errorData.error);
            } else {
         
                Alert.alert('Erreur lors de la suppression de l\'élément:', errorData.error);
            }
        }
    } catch (error) {
        Alert.alert('Erreur lors de la suppression de l\'élément:', error.message);
    }
};
    return (
        <View>
            <Header title="Détails du type de véhivcule" />
            <Text style={styles.title}>Modifier l'élément</Text>
            <Text>ID du type du véhicule: {selectedItem.idTypeVehicule}</Text>
            <InputText
                value={editedTypeVehicule}
                onChangeText={setEditedTypeVehicule}
            />
                 <View style={styles.dataContainer}>
            <BouttonConfirme onPress={handleEditItem} value="Enregistrer" />
            <BouttonConfirme onPress={handleDeleteItem} value="Supprimer" />
            </View>
            <Footer />
        </View>
    );
};

const styles = StyleSheet.create({
    title: {
        fontSize: 24,
        fontWeight: 'bold',
        textAlign: 'center',
        marginVertical: 20,
    },
    dataContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap',
        justifyContent: 'center',
    },
   
});

export default TypeVehiculeDetails;
