import React, { useEffect, useState } from 'react';
import { View, StyleSheet, Alert } from 'react-native';
import Header from '../../Components/Header';
import CustomFlatList from '../../Components/CustomFlatList'; 
import Boutton from '../../Components/Boutton';
import Footer from '../../Components/Footer';

const ListeVehicule = ({ navigation }) => {
    const [vehicules, setVehicules] = useState([]);
    const [page, setPage] = useState(1);
    const [hasMore, setHasMore] = useState(true); 
    const [totalPages, setTotalPages] = useState(0);
    const PageName = ['VehiculeDetails'];

    // Utilisation de useEffect pour charger les vehicules
    useEffect(() => {
        fetchVehicules();
    }, [page]);

    // Fonction pour récupérer les vehicules
    const fetchVehicules = () => {
        fetch(`https://sites.freeboxos.fr/Api/Vehicules/getVehicules.php?page=${page}`)
        .then((response) => response.json())
        .then((json) => {
            if (json.success) {
                setVehicules(prevVehicules => [...prevVehicules, ...json.vehicules]);
                setTotalPages(json.totalPages);
                setHasMore(page < json.totalPages);
            } else {
                Alert.alert(json.message || json.error);
            }
        })
        .catch((error) => console.error(error));
    };
    
    const keyExtractor = (item, index) => index.toString();
    const titles = ["Photo", "Marque", "Modele", "Type", "Immatriculation", "Kilometrage", "Année", "Places", "Vitesse", "Tarif Jour", "Niveau Essence"];

    const renderItem = ({ item }) => (
        <View>
            {item.image_vehicule}
            {item.nom_marque}
            {item.nom_modele}
            {item.nom_type}
            {item.Immat}
            {item.kilometrage}
            {item.annee}
            {item.Places}
            {item.BoiteVitesse}
            {item.TarifJour}
            {item.niveauCarburant}
        </View>
    );

    return (
        <View style={styles.container}>
            <Header title="Liste des véhicules" />
      
            <CustomFlatList
                data={vehicules}
                renderItem={renderItem}
                keyExtractor={keyExtractor}
                titles={titles}
                setPage={setPage}
                selectedKeys={['image_vehicule','nom_marque', 'nom_modele', 'nom_type', 'Immat', 'kilometrage', 'annee', 'Places', 'BoiteVitesse', 'TarifJour', 'niveauCarburant']}
                hasMore={hasMore} 
                PageName={PageName} 
                navigation={navigation}
          
            />
                  <Boutton onPress={() => navigation.navigate('AjoutVehicule')} value="ajouter" />
            <Footer />
        </View>
    );
};

const styles = StyleSheet.create({
    container: {
        flex: 1,
        padding: 20,
    },
});

export default ListeVehicule;
